#! /usr/bin/env python3
"""Check and show URLs in the bookmarks database that have redirects

This file is a part of Bookmarks database and Internet robot.
"""

from __future__ import print_function
import sys
from bkmk_objects import make_linear


__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2023, 2024 PhiloSoft Design"
__license__ = "GNU GPL"


def report_redirect(href, moved):
    if log_file:
        log_file.write("%s\n%s\n\n" % (href, moved))
    else:
        print("URL: %s\nMoved to: %s\n" % (href, moved))


def run():
    from getopt import getopt
    optlist, args = getopt(sys.argv[1:], "sl:")

    report_stats = 1
    global log_file
    log_filename = None

    for _opt, _arg in optlist:
        if _opt == '-s':
            report_stats = 0
        if _opt == '-l':
            log_filename = _arg
    try:
        del _opt, _arg
    except NameError:
        pass

    if report_stats:
        print("Broytman check_redirects, Copyright (C) 2023, 2024 PhiloSoft Design")

    if args:
        sys.stderr.write("check_redirects: too many arguments\n")
        sys.stderr.write("Usage: check_redirects [-s] [-l logfile]\n")
        sys.exit(1)

    if log_filename:
        log_file = open(log_filename, 'wt', encoding='utf-8')

    from storage import storage
    storage = storage()

    if report_stats:
        sys.stdout.write("Loading %s: " % storage.filename)
        sys.stdout.flush()

    root_folder = storage.load()
    make_linear(root_folder)
    objects = len(root_folder.linear)

    if report_stats:
        print("Ok")

    redirects = 0
    for object_no in range(objects):
        object = root_folder.linear[object_no]

        if object.isBookmark:
            if (hasattr(object, "error") or
                    object.href.startswith('place:')  # Firefox SmartBookmarks
                    or ('%s' in object.href)
            ):
                continue

            if hasattr(object, "moved"):
                report_redirect(object.href, object.moved)
                del object.moved
                redirects += 1

    if report_stats:
        print(objects, "objects passed")
        print(redirects, "redirects")


if __name__ == '__main__':
    run()
