#! /usr/bin/env python3
"""Get one file from an URL

This file is a part of Bookmarks database and Internet robot.
"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2024 PhiloSoft Design"
__license__ = "GNU GPL"

import argparse
import asyncio
import sys

from bkmk_objects import Bookmark


def run():
    print("Broytman get_url, Copyright (C) 2024 PhiloSoft Design")

    parser = argparse.ArgumentParser(description='Get URL')
    parser.add_argument('-H', '--headers', help='file name to save headers')
    parser.add_argument('-B', '--body', help='file name to save body')
    parser.add_argument('URL', help='URL')
    args = parser.parse_args()

    from robots import robot
    print("Using", robot)
    robot = robot(sys.stdout.write)

    url = args.URL
    bookmark = Bookmark(href=url, add_date=None)
    bookmark.parent = None

    error, redirect_code, redirect_to, headers, content = \
        asyncio.run(robot.get_url(bookmark, url, True))
    robot.stop()

    if error:
        sys.stderr.write(error + '\n')

    elif redirect_code:
        print("Moved to: %s" % redirect_to)

    else:
        if args.headers:
            with open(args.headers, 'wb') as outfile:
                outfile.write(str(headers).encode())
        else:
            print(headers)

        if args.body:
            with open(args.body, 'wb') as outfile:
                outfile.write(content)
        else:
            print(content)


if __name__ == '__main__':
    run()
